@@ -89,7 +89,7 @@ class Exceptions:
 
 class MediaTailorClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html)
     """
 
@@ -105,7 +105,7 @@ class MediaTailorClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#can_paginate)
         """
 
@@ -115,7 +115,7 @@ class MediaTailorClient(BaseClient):
         """
         Configures Amazon CloudWatch log settings for a playback configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.configure_logs_for_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.configure_logs_for_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#configure_logs_for_playback_configuration)
         """
 
@@ -125,13 +125,13 @@ class MediaTailorClient(BaseClient):
         ChannelName: str,
         Outputs: Sequence["RequestOutputItemTypeDef"],
         PlaybackMode: PlaybackModeType,
-        FillerSlate: "SlateSourceTypeDef" = None,
-        Tags: Mapping[str, str] = None
+        FillerSlate: "SlateSourceTypeDef" = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateChannelResponseTypeDef:
         """
         Creates a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_channel)
         """
 
@@ -143,12 +143,12 @@ class MediaTailorClient(BaseClient):
         ScheduleConfiguration: "ScheduleConfigurationTypeDef",
         SourceLocationName: str,
         VodSourceName: str,
-        AdBreaks: Sequence["AdBreakTypeDef"] = None
+        AdBreaks: Sequence["AdBreakTypeDef"] = ...
     ) -> CreateProgramResponseTypeDef:
         """
         Creates a program.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.create_program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.create_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_program)
         """
 
@@ -157,14 +157,14 @@ class MediaTailorClient(BaseClient):
         *,
         HttpConfiguration: "HttpConfigurationTypeDef",
         SourceLocationName: str,
-        AccessConfiguration: "AccessConfigurationTypeDef" = None,
-        DefaultSegmentDeliveryConfiguration: "DefaultSegmentDeliveryConfigurationTypeDef" = None,
-        Tags: Mapping[str, str] = None
+        AccessConfiguration: "AccessConfigurationTypeDef" = ...,
+        DefaultSegmentDeliveryConfiguration: "DefaultSegmentDeliveryConfigurationTypeDef" = ...,
+        Tags: Mapping[str, str] = ...
     ) -> CreateSourceLocationResponseTypeDef:
         """
         Creates a source location on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_source_location)
         """
 
@@ -174,12 +174,12 @@ class MediaTailorClient(BaseClient):
         HttpPackageConfigurations: Sequence["HttpPackageConfigurationTypeDef"],
         SourceLocationName: str,
         VodSourceName: str,
-        Tags: Mapping[str, str] = None
+        Tags: Mapping[str, str] = ...
     ) -> CreateVodSourceResponseTypeDef:
         """
         Creates name for a specific VOD source in a source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_vod_source)
         """
 
@@ -187,7 +187,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_channel)
         """
 
@@ -195,7 +195,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a channel's IAM policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_channel_policy)
         """
 
@@ -203,7 +203,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes the playback configuration for the specified name.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_playback_configuration)
         """
 
@@ -211,7 +211,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a specific program on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_program)
         """
 
@@ -219,7 +219,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a source location on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_source_location)
         """
 
@@ -227,7 +227,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a specific VOD source in a specific source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_vod_source)
         """
 
@@ -235,7 +235,7 @@ class MediaTailorClient(BaseClient):
         """
         Describes the properties of a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_channel)
         """
 
@@ -245,7 +245,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves the properties of the requested program.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_program)
         """
 
@@ -255,7 +255,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves the properties of the requested source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_source_location)
         """
 
@@ -265,21 +265,21 @@ class MediaTailorClient(BaseClient):
         """
         Provides details about a specific VOD source in a specific source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_vod_source)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#generate_presigned_url)
         """
 
@@ -287,7 +287,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves information about a channel's IAM policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_channel_policy)
         """
 
@@ -295,14 +295,14 @@ class MediaTailorClient(BaseClient):
         self,
         *,
         ChannelName: str,
-        DurationMinutes: str = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        DurationMinutes: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetChannelScheduleResponseTypeDef:
         """
         Retrieves information about your channel's schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_channel_schedule)
         """
 
@@ -310,48 +310,48 @@ class MediaTailorClient(BaseClient):
         """
         Returns the playback configuration for the specified name.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_playback_configuration)
         """
 
     def list_alerts(
-        self, *, ResourceArn: str, MaxResults: int = None, NextToken: str = None
+        self, *, ResourceArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAlertsResponseTypeDef:
         """
         Returns a list of alerts for the given resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.list_alerts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.list_alerts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_alerts)
         """
 
     def list_channels(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListChannelsResponseTypeDef:
         """
         Retrieves a list of channels that are associated with this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_channels)
         """
 
     def list_playback_configurations(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListPlaybackConfigurationsResponseTypeDef:
         """
         Returns a list of the playback configurations defined in AWS Elemental
         MediaTailor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_playback_configurations)
         """
 
     def list_source_locations(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListSourceLocationsResponseTypeDef:
         """
         Retrieves a list of source locations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_source_locations)
         """
 
@@ -360,17 +360,17 @@ class MediaTailorClient(BaseClient):
         Returns a list of the tags assigned to the specified playback configuration
         resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_tags_for_resource)
         """
 
     def list_vod_sources(
-        self, *, SourceLocationName: str, MaxResults: int = None, NextToken: str = None
+        self, *, SourceLocationName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListVodSourcesResponseTypeDef:
         """
         Lists all the VOD sources in a source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_vod_sources)
         """
 
@@ -378,32 +378,32 @@ class MediaTailorClient(BaseClient):
         """
         Creates an IAM policy for the channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#put_channel_policy)
         """
 
     def put_playback_configuration(
         self,
         *,
-        AdDecisionServerUrl: str = None,
-        AvailSuppression: "AvailSuppressionTypeDef" = None,
-        Bumper: "BumperTypeDef" = None,
-        CdnConfiguration: "CdnConfigurationTypeDef" = None,
-        ConfigurationAliases: Mapping[str, Mapping[str, str]] = None,
-        DashConfiguration: "DashConfigurationForPutTypeDef" = None,
-        LivePreRollConfiguration: "LivePreRollConfigurationTypeDef" = None,
-        ManifestProcessingRules: "ManifestProcessingRulesTypeDef" = None,
-        Name: str = None,
-        PersonalizationThresholdSeconds: int = None,
-        SlateAdUrl: str = None,
-        Tags: Mapping[str, str] = None,
-        TranscodeProfileName: str = None,
-        VideoContentSourceUrl: str = None
+        AdDecisionServerUrl: str = ...,
+        AvailSuppression: "AvailSuppressionTypeDef" = ...,
+        Bumper: "BumperTypeDef" = ...,
+        CdnConfiguration: "CdnConfigurationTypeDef" = ...,
+        ConfigurationAliases: Mapping[str, Mapping[str, str]] = ...,
+        DashConfiguration: "DashConfigurationForPutTypeDef" = ...,
+        LivePreRollConfiguration: "LivePreRollConfigurationTypeDef" = ...,
+        ManifestProcessingRules: "ManifestProcessingRulesTypeDef" = ...,
+        Name: str = ...,
+        PersonalizationThresholdSeconds: int = ...,
+        SlateAdUrl: str = ...,
+        Tags: Mapping[str, str] = ...,
+        TranscodeProfileName: str = ...,
+        VideoContentSourceUrl: str = ...
     ) -> PutPlaybackConfigurationResponseTypeDef:
         """
         Adds a new playback configuration to AWS Elemental MediaTailor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#put_playback_configuration)
         """
 
@@ -411,7 +411,7 @@ class MediaTailorClient(BaseClient):
         """
         Starts a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#start_channel)
         """
 
@@ -419,7 +419,7 @@ class MediaTailorClient(BaseClient):
         """
         Stops a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#stop_channel)
         """
 
@@ -427,7 +427,7 @@ class MediaTailorClient(BaseClient):
         """
         Adds tags to the specified playback configuration resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#tag_resource)
         """
 
@@ -435,7 +435,7 @@ class MediaTailorClient(BaseClient):
         """
         Removes tags from the specified playback configuration resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#untag_resource)
         """
 
@@ -445,7 +445,7 @@ class MediaTailorClient(BaseClient):
         """
         Updates an existing channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_channel)
         """
 
@@ -454,13 +454,13 @@ class MediaTailorClient(BaseClient):
         *,
         HttpConfiguration: "HttpConfigurationTypeDef",
         SourceLocationName: str,
-        AccessConfiguration: "AccessConfigurationTypeDef" = None,
-        DefaultSegmentDeliveryConfiguration: "DefaultSegmentDeliveryConfigurationTypeDef" = None
+        AccessConfiguration: "AccessConfigurationTypeDef" = ...,
+        DefaultSegmentDeliveryConfiguration: "DefaultSegmentDeliveryConfigurationTypeDef" = ...
     ) -> UpdateSourceLocationResponseTypeDef:
         """
         Updates a source location on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_source_location)
         """
 
@@ -474,7 +474,7 @@ class MediaTailorClient(BaseClient):
         """
         Updates a specific VOD source in a specific source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_vod_source)
         """
 
@@ -483,21 +483,21 @@ class MediaTailorClient(BaseClient):
         self, operation_name: Literal["get_channel_schedule"]
     ) -> GetChannelSchedulePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#getchannelschedulepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_alerts"]) -> ListAlertsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Paginator.ListAlerts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Paginator.ListAlerts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listalertspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listchannelspaginator)
         """
 
@@ -506,7 +506,7 @@ class MediaTailorClient(BaseClient):
         self, operation_name: Literal["list_playback_configurations"]
     ) -> ListPlaybackConfigurationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listplaybackconfigurationspaginator)
         """
 
@@ -515,13 +515,13 @@ class MediaTailorClient(BaseClient):
         self, operation_name: Literal["list_source_locations"]
     ) -> ListSourceLocationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listsourcelocationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_vod_sources"]) -> ListVodSourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listvodsourcespaginator)
         """
